##  Step 3: Define Relation Endpoints
Configure the endpoints of the relation using previously configured fact sheet mappings:
  1. From: Select the fact sheet mapping that represents the source endpoint of the relation. The dropdown displays all previously configured fact sheet mappings.
  2. To: Select the fact sheet mapping that represents the target endpoint of the relation. The dropdown displays all previously configured fact sheet mappings.


Choose Next after defining both endpoints.
![Screenshot showing the relation endpoints configuration step with From and To dropdown fields for selecting fact sheet mappings.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio3578a575f01a42758fc16fe34cfcf28d_LowRes.png)
Relation Endpoints Configuration
